@@ -1,25 +1,23 @@
 #include "header.h"
 
 void schlatherindfull(int *covmod, double *data, double *dist, int *nSite, int *nObs, int *dim,
-		      int *weighted, double *weights, double *locs, double *scales, double *shapes, 
+		      int *weighted, double *weights, double *locs, double *scales, double *shapes,
 		      double *alpha, double *nugget, double *range, double *smooth,
 		      double *smooth2, int *fitmarge,double *dns){
   //This is the independent Schlater's model. It's a wrapper to several
   //sub-functions. It's named xxxfull as it either assume that the
   //margins are unit Frechet, or the GEV parameters are estimated at
   //each locations.
-  
+
   const int nPairs = *nSite * (*nSite - 1) / 2;
-  int i;
-  double *jac, *rho, *frech;
-  
-  jac = (double *)R_alloc(*nSite * *nObs, sizeof(double));
-  rho = (double *)R_alloc(nPairs, sizeof(double));
-  frech = (double *)R_alloc(*nSite * *nObs, sizeof(double));
+
+  double *jac = (double *)R_alloc(*nSite * *nObs, sizeof(double)),
+    *rho = (double *)R_alloc(nPairs, sizeof(double)),
+    *frech = (double *)R_alloc(*nSite * *nObs, sizeof(double));
 
   //Some preliminary steps: Valid points?
   if (*fitmarge){
-    for (i=0;i<*nSite;i++){
+    for (int i=0;i<*nSite;i++){
       if ((scales[i] <= 0) || (shapes[i] <= -1)){
 	//printf("scales <= 0!!!\n");
 	*dns = MINF;
@@ -37,7 +35,7 @@ void schlatherindfull(int *covmod, double *data, double *dist, int *nSite, int *
     *dns = *nugget * *nugget * MINF;
     return;
   }
-   
+
   //Stage 0: Compute the covariance at each location
   switch (*covmod){
   case 1:
@@ -56,10 +54,10 @@ void schlatherindfull(int *covmod, double *data, double *dist, int *nSite, int *
     *dns = caugen(dist, nPairs, *nugget, 1 - *nugget, *range, *smooth, *smooth2, rho);
     break;
   }
-  
+
   if (*dns != 0.0)
     return;
-  
+
   //Stage 1: Transformation to unit Frechet
   if (*fitmarge){
     *dns = gev2frech(data, *nObs, *nSite, locs, scales, shapes,
@@ -67,16 +65,16 @@ void schlatherindfull(int *covmod, double *data, double *dist, int *nSite, int *
 
     if (*dns != 0.0)
       return;
-    
+
     if (*weighted)
       *dns = wlplikschlatherind(frech, *alpha, rho, jac, *nObs, *nSite, weights);
 
     else
       *dns = lplikschlatherind(frech, *alpha, rho, jac, *nObs, *nSite);
   }
-  
+
   else {
-    for (i=(*nSite * *nObs);i--;)
+    for (int i=0;i<(*nSite * *nObs);i++)
       jac[i] = 0;
 
     if (*weighted)
@@ -85,7 +83,7 @@ void schlatherindfull(int *covmod, double *data, double *dist, int *nSite, int *
     else
       *dns = lplikschlatherind(frech, *alpha, rho, jac, *nObs, *nSite);
   }
-  
+
   if (!R_FINITE(*dns))
     *dns = MINF;
 
@@ -111,18 +109,18 @@ void schlatherinddsgnmat(int *covmod, double *data, double *dist, int *nSite, in
   //This is the independent Schlater's model.
   //The GEV parameters are defined using a polynomial response surface
   //or p-splines.
-  
+
   const int nPairs = *nSite * (*nSite - 1) / 2;
   int flag = usetempcov[0] + usetempcov[1] + usetempcov[2];
   double *jac, *rho, *locs, *scales, *shapes, *frech, *trendlocs, *trendscales, *trendshapes;
-    
+
   jac = (double *)R_alloc(*nObs * *nSite, sizeof(double));
   rho = (double *)R_alloc(nPairs, sizeof(double));
   locs = (double *)R_alloc(*nSite, sizeof(double));
   scales = (double *)R_alloc(*nSite, sizeof(double));
   shapes = (double *)R_alloc(*nSite, sizeof(double));
   frech = (double *)R_alloc(*nObs * *nSite, sizeof(double));
-  
+
   if ((*alpha < 0) || (*alpha > 1)){
     *dns = MINF;
     return;
@@ -154,13 +152,12 @@ void schlatherinddsgnmat(int *covmod, double *data, double *dist, int *nSite, in
 
   if (*dns != 0.0)
     return;
-  
+
   //Stage 2: Compute the GEV parameters using the design matrix
   *dns = dsgnmat2Param(locdsgnmat, scaledsgnmat, shapedsgnmat, loccoeff, scalecoeff, shapecoeff,
 		       *nSite, *nloccoeff, *nscalecoeff, *nshapecoeff, locs, scales, shapes);
 
   if (flag){
-    int i, j;
     trendlocs = (double *)R_alloc(*nObs, sizeof(double));
     trendscales = (double *)R_alloc(*nObs, sizeof(double));
     trendshapes = (double *)R_alloc(*nObs, sizeof(double));
@@ -169,8 +166,8 @@ void schlatherinddsgnmat(int *covmod, double *data, double *dist, int *nSite, in
 		      tempcoeffscale, tempcoeffshape, *nSite, *nObs, usetempcov, *ntempcoeffloc,
 		      *ntempcoeffscale, *ntempcoeffshape, trendlocs, trendscales, trendshapes);
 
-    for (i=*nSite;i--;)
-      for (j=*nObs;j--;)
+    for (int i=0;i<*nSite;i++)
+      for (int j=0;j<*nObs;j++)
 	if (((scales[i] + trendscales[j]) <= 0) || ((shapes[i] + trendshapes[j]) <= -1)){
 	  *dns = MINF;
 	  return;
@@ -196,20 +193,20 @@ void schlatherinddsgnmat(int *covmod, double *data, double *dist, int *nSite, in
 
   else
     *dns = wlplikschlatherind(frech, *alpha, rho, jac, *nObs, *nSite, weights);
-    
+
   //Stage 5: Removing the penalizing terms (if any)
   // 1- For the location parameter
   if (*locpenalty > 0)
     *dns -= penalization(locpenmat, loccoeff, *locpenalty, *nloccoeff, *npparloc);
-  
+
   // 2- For the scale parameter
-  if (*scalepenalty > 0)    
+  if (*scalepenalty > 0)
     *dns -= penalization(scalepenmat, scalecoeff, *scalepenalty, *nscalecoeff, *npparscale);
-  
+
   // 3- For the shape parameter
   if (*shapepenalty > 0)
     *dns -= penalization(shapepenmat, shapecoeff, *shapepenalty, *nshapecoeff, *npparshape);
-  
+
   // 4- Doing the same thing for the temporal component
   if (*temppenaltyloc > 0)
     *dns -= penalization(temppenmatloc, tempcoeffloc, *temppenaltyloc, *ntempcoeffloc,
@@ -227,5 +224,5 @@ void schlatherinddsgnmat(int *covmod, double *data, double *dist, int *nSite, in
     *dns = MINF;
 
   return;
-  
+
 }
