@@ -14,7 +14,7 @@ void spatgevlik(double *data, double *covariables, int *nSite, int *nObs,
 		double *temppenaltyshape, double *loccoeff, double *scalecoeff,
 		double *shapecoeff, double *tempcoeffloc, double *tempcoeffscale,
 		double *tempcoeffshape, double *dns){
-  
+
   /* This function computes the log-likelihood for a spatial GEV model
      i.e. the GEV paramters are defined through a response surface
      that could be either is simple linear model or a p-spline. */
@@ -25,7 +25,7 @@ void spatgevlik(double *data, double *covariables, int *nSite, int *nObs,
   double *locs = (double *)R_alloc(*nSite, sizeof(double)),
     *scales = (double *)R_alloc(*nSite, sizeof(double)),
     *shapes = (double *)R_alloc(*nSite, sizeof(double));
-  
+
   //Stage 1: Computing the GEV parameters using the design matrix
   *dns = dsgnmat2Param(locdsgnmat, scaledsgnmat, shapedsgnmat, loccoeff, scalecoeff,
 		       shapecoeff, *nSite, *nloccoeff, *nscalecoeff, *nshapecoeff, locs,
@@ -47,7 +47,7 @@ void spatgevlik(double *data, double *covariables, int *nSite, int *nObs,
 	  return;
 	}
   }
-  
+
   else if (*dns != 0.0)
     return;
 
@@ -56,24 +56,27 @@ void spatgevlik(double *data, double *covariables, int *nSite, int *nObs,
   if (flag){
     for (int i=0;i<*nSite;i++){
       for (int j=0;j<*nObs;j++){
+	if (ISNA(data[j + i * *nObs]))
+	  continue;
+
 	if (fabs(shapes[i] + trendshapes[j]) <= 1e-6){
 	  data[j + i * *nObs] = (data[j + i * *nObs] - locs[i] - trendlocs[j]) /
 	    (scales[i] + trendscales[j]);
-	  
+
 	  *dns += -log(scales[i] + trendscales[j]) - data[j + i * *nObs] -
 	    exp(-data[j + i * *nObs]);
 	}
-      
+
       else{
-	data[j + i * *nObs] = 1 + (shapes[i] + trendshapes[j]) * 
+	data[j + i * *nObs] = 1 + (shapes[i] + trendshapes[j]) *
 	  (data[j + i * *nObs] - locs[i] - trendlocs[j]) / (scales[i] + trendscales[j]);
-	  
+
 	  if (data[j + i * *nObs] <= 0){
 	    *dns = MINF;
 	    return;
 	  }
-	  
-	  *dns += -log(scales[i] + trendscales[j]) - 
+
+	  *dns += -log(scales[i] + trendscales[j]) -
 	    R_pow(data[j + i * *nObs], -1 / (shapes[i] + trendshapes[j])) -
 	    (1 / (shapes[i] + trendshapes[j]) + 1) * log(data[j + i * *nObs]);
 	}
@@ -83,27 +86,33 @@ void spatgevlik(double *data, double *covariables, int *nSite, int *nObs,
 
   else {
     for (int i=0;i<*nSite;i++){
-      
+
       if (fabs(shapes[i]) <= 1e-6){
 	for (int j=0;j<*nObs;j++){
+	  if (ISNA(data[j + i * *nObs]))
+	    continue;
+
 	  data[j + i * *nObs] = (data[j + i * *nObs] - locs[i]) /
 	    scales[i];
-	  
+
 	  *dns += -log(scales[i]) - data[j + i * *nObs] -
 	    exp(-data[j + i * *nObs]);
 	}
       }
-      
+
       else{
 	for (int j=0;j<*nObs;j++){
+	  if (ISNA(data[j + i * *nObs]))
+	    continue;
+
 	  data[j + i * *nObs] = 1 + shapes[i] * (data[j + i * *nObs] - locs[i]) /
 	    scales[i];
-	  
+
 	  if (data[j + i * *nObs] <= 0){
 	    *dns = MINF;
 	    return;
 	  }
-	  
+
 	  *dns += -log(scales[i]) - R_pow(data[j + i * *nObs], -1/shapes[i]) -
 	    (1/shapes[i] + 1) * log(data[j + i * *nObs]);
 	}
@@ -116,12 +125,12 @@ void spatgevlik(double *data, double *covariables, int *nSite, int *nObs,
   if (*locpenalty > 0)
     *dns -= penalization(locpenmat, loccoeff, *locpenalty,
 			 *nloccoeff, *npparloc);
-  
+
   // 2- For the scale parameter
-  if (*scalepenalty > 0)    
+  if (*scalepenalty > 0)
     *dns -= penalization(scalepenmat, scalecoeff, *scalepenalty,
 			 *nscalecoeff, *npparscale);
-  
+
   // 3- For the shape parameter
   if (*shapepenalty > 0)
     *dns -= penalization(shapepenmat, shapecoeff, *shapepenalty,
@@ -139,8 +148,8 @@ void spatgevlik(double *data, double *covariables, int *nSite, int *nObs,
   if (*temppenaltyshape > 0)
     *dns -= penalization(temppenmatshape, tempcoeffshape, *temppenaltyshape,
 			 *ntempcoeffshape, *nppartempcoeffshape);
-  
+
   return;
 }
 
-	  
+
